@@ -120,6 +120,17 @@ def getwvTableByEntityID(access_token,subscription_key,rootUrl,activeOU,wellview
     IDWELL = r.get(url=url,headers=call_headers)
     return IDWELL
 
+def getwvTableByEntityID_singleFilter(access_token,subscription_key,rootUrl,activeOU,wellview,table,cursor,pagesize,entityId,filterColumn,filterValue):
+    call_headers = {
+                "Content-Type":'application/json',
+                "Authorization":"Bearer %s" %(access_token),
+                "Ocp-Apim-Subscription-Key":subscription_key,
+                "wellview":wellview
+                }
+    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{entityId}?${filterColumn}=${filterValue}&?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
+    IDWELL = r.get(url=url,headers=call_headers)
+    return IDWELL
+
 def getwvTableForParent(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor,parentId):
     call_headers = {
                 "Content-Type":'application/json',
@@ -130,3 +141,16 @@ def getwvTableForParent(access_token,subscription_key,rootUrl,activeOU,wellview,
     url = F"{rootUrl}/{activeOU}/wellview/data/{table}/parentId/{parentId}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
     IDWELL = r.get(url=url,headers=call_headers)
     return IDWELL
+
+
+def putwvColumnByIDREC(access_token,subscription_key,rootUrl,activeOU,wellview,table,idwell,idrec,column,writeVal):
+    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{idwell}/recordId/{idrec}/{column}"
+    put_headers = {
+                "Content-Type":'application/json',
+                "Authorization":"Bearer %s" %(access_token),
+                "Ocp-Apim-Subscription-Key":subscription_key,
+                "wellview":wellview
+                }
+    payload = json.dumps(writeVal)         
+    updateColumn = r.put(url=url,headers=put_headers,data=payload)
+    return updateColumn
